@@ -3,20 +3,21 @@
 
 # event.py --- Example of a trait event
 
-#--<Imports>--------------------------------------------------------------------
+#--<Imports>-------------------------------------------------------------------
 from traits.api import Event, HasTraits, List, RGBColor, Tuple
 
-#--[Code]-----------------------------------------------------------------------
+#--[Code]----------------------------------------------------------------------
 
 point_2d = Tuple(0, 0)
 
+
 class Line2D(HasTraits):
     points = List(point_2d)
     line_color = RGBColor('black')
     updated = Event
 
-    def redraw():
-        pass # Not implemented for this example
+    def redraw(self):
+        pass  # Not implemented for this example
 
     def _points_changed(self):
         self.updated = True
