@@ -1,5 +1,6 @@
-""" Test the adapter manager. """
+""" Test the adaptation manager. """
 
+import sys
 
 from traits.adaptation.api import AdaptationManager, adapt
 import traits.adaptation.tests.abc_examples
@@ -8,7 +9,7 @@ from traits.testing.unittest_tools import unittest
 
 
 class TestAdaptationManagerWithABC(unittest.TestCase):
-    """ Test the adapter manager. """
+    """ Test the adaptation manager. """
 
     #: Class attribute pointing at the module containing the example data
     examples = traits.adaptation.tests.abc_examples
@@ -39,13 +40,13 @@ class TestAdaptationManagerWithABC(unittest.TestCase):
         uk_plug = self.adaptation_manager.adapt(plug, ex.UKPlug)
 
         # The adaptation manager should simply return the same object.
-        self.assert_(uk_plug is plug)
+        self.assertIs(uk_plug, plug)
 
         # Try to adapt it to an ABC that is registered for its type.
         uk_plug = self.adaptation_manager.adapt(plug, ex.UKStandard)
 
         # The adaptation manager should simply return the same object.
-        self.assert_(uk_plug is plug)
+        self.assertIs(uk_plug, plug)
 
         return
 
@@ -118,7 +119,7 @@ class TestAdaptationManagerWithABC(unittest.TestCase):
         japan_plug = self.adaptation_manager.adapt(uk_plug, ex.JapanStandard)
         self.assertIsNotNone(japan_plug)
         self.assertIsInstance(japan_plug, ex.EUStandardToJapanStandard)
-        self.assert_(japan_plug.adaptee.adaptee is uk_plug)
+        self.assertIs(japan_plug.adaptee.adaptee, uk_plug)
 
         return
 
@@ -161,7 +162,7 @@ class TestAdaptationManagerWithABC(unittest.TestCase):
         iraq_plug = self.adaptation_manager.adapt(uk_plug, ex.IraqStandard)
         self.assertIsNotNone(iraq_plug)
         self.assertIsInstance(iraq_plug, ex.EUStandardToIraqStandard)
-        self.assert_(iraq_plug.adaptee.adaptee is uk_plug)
+        self.assertIs(iraq_plug.adaptee.adaptee, uk_plug)
 
         return
 
@@ -207,7 +208,7 @@ class TestAdaptationManagerWithABC(unittest.TestCase):
             type(iraq_plug),
             [ex.EUStandardToIraqStandard, ex.JapanStandardToIraqStandard]
         )
-        self.assert_(iraq_plug.adaptee.adaptee is uk_plug)
+        self.assertIs(iraq_plug.adaptee.adaptee, uk_plug)
 
         return
 
@@ -506,7 +507,7 @@ class TestAdaptationManagerWithABC(unittest.TestCase):
         # Adaptation to B should succeed through D
         b = self.adaptation_manager.adapt(c, B)
         self.assertIsNotNone(b)
-        self.assert_(hasattr(b, 'marker'))
+        self.assertTrue(hasattr(b, 'marker'))
 
         return
 
@@ -520,7 +521,7 @@ class TestAdaptationManagerWithABC(unittest.TestCase):
         class IB(IA):
             pass
 
-        self.assert_(self.adaptation_manager.provides_protocol(IB, IA))
+        self.assertTrue(self.adaptation_manager.provides_protocol(IB, IA))
 
         return
 
@@ -546,6 +547,12 @@ class TestAdaptationManagerWithInterfaces(TestAdaptationManagerWithABC):
 
     def test_adapts_should_register_class_as_providing_the_to_protocol(self):
 
+        if sys.version_info[0] >= 3:
+            self.skipTest("""
+                Currently, under Python 3, class advisors do not work anymore.
+                Therefore, this test will fail due to the use of "adapts".
+            """)
+
         from traits.api import Adapter, adapts, HasTraits, Instance, \
              Int, Interface
 
