@@ -1,5 +1,3 @@
-#-------------------------------------------------------------------------------
-#
 #  Copyright (c) 2007, Enthought, Inc.
 #  All rights reserved.
 #
@@ -7,11 +5,6 @@
 #  license included in /LICENSE.txt and may be redistributed only
 #  under the conditions described in the aforementioned license.  The license
 #  is also available online at http://www.enthought.com/licenses/BSD.txt
-#
-#  Thanks for using Enthought open source!
-#
-#
-#-------------------------------------------------------------------------------
 
 from __future__ import absolute_import
 
@@ -23,36 +16,41 @@ from ..api import HasTraits, Instance, Str
 class Shared(HasTraits):
     s = Str('new instance of Shared')
 
+
 class Foo(HasTraits):
     s = Str('new instance of Foo')
     shared = Instance(Shared)
 
+
 class Bar(HasTraits):
     s = Str('new instance of Bar')
     foo = Instance(Foo)
     shared = Instance(Shared)
 
+
 class Baz(HasTraits):
     s = Str('new instance of Baz')
     bar = Instance(Bar)
     shared = Instance(Shared)
 
-class CopyTraitsBase( unittest.TestCase ):
+
+class CopyTraitsBase(unittest.TestCase):
     """ Validate that copy_traits
     """
     __test__ = False
+
     def setUp(self):
         print '\n**CopyTraitsBase.setUp ',
-        super(CopyTraitsBase,self).setUp()
+        super(CopyTraitsBase, self).setUp()
         self.shared = Shared(s='shared')
         self.foo = Foo(shared=self.shared, s='foo')
         self.bar = Bar(shared=self.shared, foo=self.foo, s='bar')
         self.baz = Baz(shared=self.shared, bar=self.bar, s='baz')
 
-        self.shared2 = Shared( s='shared2' )
-        self.foo2 = Foo( shared=self.shared2, s='foo2' )
-        self.bar2 = Bar( shared=self.shared2, foo=self.foo2, s='bar2' )
-        self.baz2 = Baz( shared=self.shared2, bar=self.bar2, s='baz2' )
+        self.shared2 = Shared(s='shared2')
+        self.foo2 = Foo(shared=self.shared2, s='foo2')
+        self.bar2 = Bar(shared=self.shared2, foo=self.foo2, s='bar2')
+        self.baz2 = Baz(shared=self.shared2, bar=self.bar2, s='baz2')
 
         return
 
@@ -77,11 +75,12 @@ class CopyTraitsBase( unittest.TestCase ):
         # self.baz2.base_trait('shared').copy = value
         #self.print_copy()
 
-class TestCopyTraitsSetup( CopyTraitsBase ):
 
+class TestCopyTraitsSetup(CopyTraitsBase):
     __test__ = True
+
     def setUp(self):
-        super(TestCopyTraitsSetup,self).setUp()
+        super(TestCopyTraitsSetup, self).setUp()
         print '\nshared', self.shared
         print 'foo', self.foo
         print 'bar', self.bar
@@ -94,21 +93,20 @@ class TestCopyTraitsSetup( CopyTraitsBase ):
         return
 
     def test_setup(self):
-        self.failUnless( self.foo is self.bar.foo )
-        self.failUnless( self.bar is self.baz.bar )
-        self.failUnless( self.foo.shared is self.shared )
-        self.failUnless( self.bar.shared is self.shared )
-        self.failUnless( self.baz.shared is self.shared )
+        self.failUnless(self.foo is self.bar.foo)
+        self.failUnless(self.bar is self.baz.bar)
+        self.failUnless(self.foo.shared is self.shared)
+        self.failUnless(self.bar.shared is self.shared)
+        self.failUnless(self.baz.shared is self.shared)
 
-        self.failUnless( self.foo2 is self.bar2.foo )
-        self.failUnless( self.bar2 is self.baz2.bar )
-        self.failUnless( self.foo2.shared is self.shared2 )
-        self.failUnless( self.bar2.shared is self.shared2 )
-        self.failUnless( self.baz2.shared is self.shared2 )
+        self.failUnless(self.foo2 is self.bar2.foo)
+        self.failUnless(self.bar2 is self.baz2.bar)
+        self.failUnless(self.foo2.shared is self.shared2)
+        self.failUnless(self.bar2.shared is self.shared2)
+        self.failUnless(self.baz2.shared is self.shared2)
         return
 
 
-
 class CopyTraits:
 
     def test_baz2_s(self):
@@ -132,17 +130,17 @@ class CopyTraits:
         # First hand Instance trait is different and
         # is not the same object as the source.
 
-        self.failIf( self.baz2.bar is None)
-        self.failIf( self.baz2.bar is self.bar2 )
-        self.failIf( self.baz2.bar is self.baz.bar )
+        self.failIf(self.baz2.bar is None)
+        self.failIf(self.baz2.bar is self.bar2)
+        self.failIf(self.baz2.bar is self.baz.bar)
 
     def test_baz2_bar_foo(self):
         # Second hand Instance trait is a different object and
         # is not the same object as the source.
 
-        self.failIf( self.baz2.bar.foo is None)
-        self.failIf( self.baz2.bar.foo is self.foo2 )
-        self.failIf( self.baz2.bar.foo is self.baz.bar.foo )
+        self.failIf(self.baz2.bar.foo is None)
+        self.failIf(self.baz2.bar.foo is self.foo2)
+        self.failIf(self.baz2.bar.foo is self.baz.bar.foo)
 
 
 class CopyTraitsSharedCopyNone:
@@ -150,9 +148,9 @@ class CopyTraitsSharedCopyNone:
         # First hand Instance trait is a different object and
         # is not the same object as the source.
 
-        self.failIf( self.baz2.shared is None)
-        self.failIf( self.baz2.shared is self.shared2)
-        self.failIf( self.baz2.shared is self.shared)
+        self.failIf(self.baz2.shared is None)
+        self.failIf(self.baz2.shared is self.shared2)
+        self.failIf(self.baz2.shared is self.shared)
 
     def test_baz2_bar_shared(self):
         # Second hand Instance that was shared is a different object and
@@ -160,10 +158,10 @@ class CopyTraitsSharedCopyNone:
         # not the same object as the new first hand instance that was the same.
         # I.e. There are now (at least) two copies of one original object.
 
-        self.failIf( self.baz2.bar.shared is None )
-        self.failIf( self.baz2.bar.shared is self.shared2 )
-        self.failIf( self.baz2.bar.shared is self.shared )
-        self.failIf( self.baz2.bar.shared is self.baz2.shared )
+        self.failIf(self.baz2.bar.shared is None)
+        self.failIf(self.baz2.bar.shared is self.shared2)
+        self.failIf(self.baz2.bar.shared is self.shared)
+        self.failIf(self.baz2.bar.shared is self.baz2.shared)
 
     def test_baz2_bar_foo_shared(self):
         # Third hand Instance that was shared is a different object and
@@ -171,14 +169,15 @@ class CopyTraitsSharedCopyNone:
         # not the same object as the new first hand instance that was the same.
         # I.e. There are now (at least) two copies of one original object.
 
-        self.failIf( self.baz2.bar.foo.shared is None )
-        self.failIf( self.baz2.bar.foo.shared is self.shared2 )
-        self.failIf( self.baz2.bar.foo.shared is self.shared )
-        self.failIf( self.baz2.bar.foo.shared is self.baz2.shared )
+        self.failIf(self.baz2.bar.foo.shared is None)
+        self.failIf(self.baz2.bar.foo.shared is self.shared2)
+        self.failIf(self.baz2.bar.foo.shared is self.shared)
+        self.failIf(self.baz2.bar.foo.shared is self.baz2.shared)
 
     def test_baz2_bar_and_foo_shared(self):
         #
-        # THE BEHAVIOR DEMONSTRATED BY THIS TEST CASE DOES NOT SEEM TO BE CORRECT.
+        # THE BEHAVIOR DEMONSTRATED BY THIS TEST CASE DOES NOT SEEM TO BE
+        # CORRECT.
         #
         # Second and Third hand Instance object that was shared with first hand
         # instance are the same as each other but
@@ -187,13 +186,14 @@ class CopyTraitsSharedCopyNone:
         # first hand reference which is a different copy.
         # I.e. The shared relationship has been fubarred by copy_traits: it's
         # not maintained, but not completely destroyed.
-        self.failUnless( self.baz2.bar.shared is self.baz2.bar.foo.shared )
-        self.failIf( self.baz2.shared is self.baz2.bar.foo.shared )
+        self.failUnless(self.baz2.bar.shared is self.baz2.bar.foo.shared)
+        self.failIf(self.baz2.shared is self.baz2.bar.foo.shared)
 
 
-class TestCopyTraitsSharedCopyNone( CopyTraits,
-                                    CopyTraitsSharedCopyNone ):
+class TestCopyTraitsSharedCopyNone(CopyTraits,
+                                   CopyTraitsSharedCopyNone):
     __test__ = False
+
     def setUp(self):
         print '\n***TestCopyTraitsSharedCopyNone',
         #super(TestCopyTraitsSharedCopyNone,self).setUp()
@@ -202,119 +202,116 @@ class TestCopyTraitsSharedCopyNone( CopyTraits,
         self.set_shared_copy('deep')
         return
 
-class TestCopyTraitsCopyNotSpecified( CopyTraitsBase, TestCopyTraitsSharedCopyNone ):
 
+class TestCopyTraitsCopyNotSpecified(CopyTraitsBase,
+                                     TestCopyTraitsSharedCopyNone):
     __test__ = True
+
     def setUp(self):
         print '\n*TestCopyTraitsCopyNotSpecified',
 #        super(TestCopyTraitsCopyNotSpecified,self).setUp()
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyNone.setUp(self)
-        self.baz2.copy_traits( self.baz )
+        self.baz2.copy_traits(self.baz)
         return
 
 
-class TestCopyTraitsCopyShallow( CopyTraitsBase, TestCopyTraitsSharedCopyNone ):
-
+class TestCopyTraitsCopyShallow(CopyTraitsBase, TestCopyTraitsSharedCopyNone):
     __test__ = True
+
     def setUp(self):
         print '\n*TestCopyTraitsCopyShallow',
 #        super(TestCopyTraitsCopyShallow,self).setUp()
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyNone.setUp(self)
-        self.baz2.copy_traits( self.baz, copy='shallow' )
+        self.baz2.copy_traits(self.baz, copy='shallow')
         return
 
-class TestCopyTraitsCopyDeep( CopyTraitsBase, TestCopyTraitsSharedCopyNone ):
 
+class TestCopyTraitsCopyDeep(CopyTraitsBase, TestCopyTraitsSharedCopyNone):
     __test__ = True
+
     def setUp(self):
         print '\n*TestCopyTraitsCopyDeep',
 #        super(TestCopyTraitsCopyDeep,self).setUp()
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyNone.setUp(self)
-        self.baz2.copy_traits( self.baz, copy='deep' )
+        self.baz2.copy_traits(self.baz, copy='deep')
         return
 
 
-
-
-
 class CopyTraitsSharedCopyRef:
     def test_baz2_shared(self):
         # First hand Instance trait is a different object and
         # is the same object as the source.
 
-        self.failIf( self.baz2.shared is None)
-        self.failIf( self.baz2.shared is self.shared2)
-        self.failUnless( self.baz2.shared is self.shared)
+        self.failIf(self.baz2.shared is None)
+        self.failIf(self.baz2.shared is self.shared2)
+        self.failUnless(self.baz2.shared is self.shared)
 
     def test_baz2_bar_shared(self):
-        self.failIf( self.baz2.bar.shared is None )
-        self.failIf( self.baz2.bar.shared is self.shared2 )
-        self.failUnless( self.baz2.bar.shared is self.shared )
-        self.failUnless( self.baz2.bar.shared is self.baz2.shared )
+        self.failIf(self.baz2.bar.shared is None)
+        self.failIf(self.baz2.bar.shared is self.shared2)
+        self.failUnless(self.baz2.bar.shared is self.shared)
+        self.failUnless(self.baz2.bar.shared is self.baz2.shared)
 
     def test_baz2_bar_foo_shared(self):
-        self.failIf( self.baz2.bar.foo.shared is None )
-        self.failIf( self.baz2.bar.foo.shared is self.shared2 )
-        self.failUnless( self.baz2.bar.foo.shared is self.shared )
-        self.failUnless( self.baz2.bar.foo.shared is self.baz2.shared )
+        self.failIf(self.baz2.bar.foo.shared is None)
+        self.failIf(self.baz2.bar.foo.shared is self.shared2)
+        self.failUnless(self.baz2.bar.foo.shared is self.shared)
+        self.failUnless(self.baz2.bar.foo.shared is self.baz2.shared)
 
     def test_baz2_bar_and_foo_shared(self):
-        self.failUnless( self.baz2.bar.shared is self.baz2.bar.foo.shared )
-        self.failUnless( self.baz2.shared is self.baz2.bar.foo.shared )
+        self.failUnless(self.baz2.bar.shared is self.baz2.bar.foo.shared)
+        self.failUnless(self.baz2.shared is self.baz2.bar.foo.shared)
 
 
-class TestCopyTraitsSharedCopyRef( CopyTraits,
-                                    CopyTraitsSharedCopyRef ):
+class TestCopyTraitsSharedCopyRef(CopyTraits,
+                                  CopyTraitsSharedCopyRef):
     __test__ = False
+
     def setUp(self):
         print '\n***TestCopyTraitsSharedCopyRef.setUp ',
         #super(TestCopyTraitsSharedCopyRef,self).setUp()
         self.set_shared_copy('ref')
         return
 
+
 # The next three tests demonstrate that a 'ref' trait is always copied as a
 # reference regardless of the copy argument to copy_traits.  That is, shallow
 # and deep are indistinguishable.
-
-class TestCopyTraitsCopyNotSpecifiedSharedRef( CopyTraitsBase, TestCopyTraitsSharedCopyRef):
-
+class TestCopyTraitsCopyNotSpecifiedSharedRef(CopyTraitsBase,
+                                              TestCopyTraitsSharedCopyRef):
     __test__ = True
+
     def setUp(self):
         print '\n*TestCopyTraitsCopyNotSpecifiedSharedRef.setUp',
-#        super(TestCopyTraitsCopyNotSpecifiedSharedRef,self).setUp()
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyRef.setUp(self)
-        self.baz2.copy_traits( self.baz )
+        self.baz2.copy_traits(self.baz)
         return
 
 
-class TestCopyTraitsCopyShallowSharedRef( CopyTraitsBase, TestCopyTraitsSharedCopyRef ):
-
+class TestCopyTraitsCopyShallowSharedRef(CopyTraitsBase,
+                                         TestCopyTraitsSharedCopyRef):
     __test__ = True
+
     def setUp(self):
         print '\n*TestCopyTraitsCopyShallowSharedRef.setUp',
-#        super(TestCopyTraitsCopyShallowSharedRef,self).setUp()
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyRef.setUp(self)
-        self.baz2.copy_traits( self.baz, copy='shallow' )
+        self.baz2.copy_traits(self.baz, copy='shallow')
         return
 
-class TestCopyTraitsCopyDeepSharedRef( CopyTraitsBase, TestCopyTraitsSharedCopyRef ):
 
+class TestCopyTraitsCopyDeepSharedRef(CopyTraitsBase,
+                                      TestCopyTraitsSharedCopyRef):
     __test__ = True
+
     def setUp(self):
         print '\n*TestCopyTraitsCopyDeepSharedRef.setUp',
-#        super(TestCopyTraitsCopyDeepSharedRef,self).setUp()
         CopyTraitsBase.setUp(self)
         TestCopyTraitsSharedCopyRef.setUp(self)
-        self.baz2.copy_traits( self.baz, copy='deep' )
+        self.baz2.copy_traits(self.baz, copy='deep')
         return
-
-
-
 ### EOF
-
-
