@@ -1,5 +1,3 @@
-#-------------------------------------------------------------------------------
-#
 #  Test the 'add_trait_listener', 'remove_trait_listener' interface to
 #  the HasTraits class.
 #
@@ -18,12 +16,6 @@
 #  available online at http://www.enthought.com/licenses/BSD.txt
 #
 #  Thanks for using Enthought open source!
-#
-#-------------------------------------------------------------------------------
-
-#-------------------------------------------------------------------------------
-#  Imports:
-#-------------------------------------------------------------------------------
 
 from __future__ import absolute_import
 
@@ -38,9 +30,6 @@ from traits.testing.unittest_tools import unittest
 from ..api import HasTraits, Str, Int, Float, Any, Event
 from ..api import push_exception_handler, pop_exception_handler
 
-#-------------------------------------------------------------------------------
-#  captured_stderr helper context manager
-#-------------------------------------------------------------------------------
 
 @contextlib.contextmanager
 def captured_stderr():
@@ -57,53 +46,36 @@ def captured_stderr():
         sys.stderr = original_stderr
 
 
-#-------------------------------------------------------------------------------
-#  'GenerateEvents' class:
-#-------------------------------------------------------------------------------
-
-class GenerateEvents ( HasTraits ):
-
-    #---------------------------------------------------------------------------
-    #  Trait definitions:
-    #---------------------------------------------------------------------------
-
-    name   = Str
-    age    = Int
+class GenerateEvents(HasTraits):
+    name = Str
+    age = Int
     weight = Float
 
-#-------------------------------------------------------------------------------
-#  'ListenEvents' class:
-#-------------------------------------------------------------------------------
+events = {}  # dict of events
 
-events = {} # dict of events
 
-class ListenEvents ( HasTraits ):
+class ListenEvents(HasTraits):
 
-    #---------------------------------------------------------------------------
     #  'GenerateEvents' event interface:
     #  the events are stored in the dict 'events'
-    #---------------------------------------------------------------------------
 
-    def _name_changed ( self, object, name, old, new ):
+    def _name_changed(self, object, name, old, new):
         events["_name_changed"] = (name, old, new)
 
-    def _age_changed ( self, object, name, old, new ):
+    def _age_changed(self, object, name, old, new):
         events["_age_changed"] = (name, old, new)
 
-    def _weight_changed ( self, object, name, old, new ):
+    def _weight_changed(self, object, name, old, new):
         events["_weight_changed"] = (name, old, new)
 
-    def alt_name_changed ( self, object, name, old, new ):
+    def alt_name_changed(self, object, name, old, new):
         events["alt_name_changed"] = (name, old, new)
 
-    def alt_weight_changed ( self, object, name, old, new ):
+    def alt_weight_changed(self, object, name, old, new):
         events["alt_weight_changed"] = (name, old, new)
 
-#-------------------------------------------------------------------------------
-#  unit test class:
-#-------------------------------------------------------------------------------
 
-class Test_Listeners ( unittest.TestCase ):
+class Test_Listeners(unittest.TestCase):
 
     def test(self):
         global events
@@ -113,12 +85,12 @@ class Test_Listeners ( unittest.TestCase ):
         le = ListenEvents()
 
         # Starting test: No Listeners
-        ge.set( name = 'Joe', age = 22, weight = 152.0 )
+        ge.set(name='Joe', age=22, weight=152.0)
 
         # Adding default listener
-        ge.add_trait_listener( le )
+        ge.add_trait_listener(le)
         events = {}
-        ge.set( name = 'Mike', age = 34, weight = 178.0 )
+        ge.set(name='Mike', age=34, weight=178.0)
         self.assertEqual(events, {
             '_age_changed': ('age', 22, 34),
             '_weight_changed': ('weight', 152.0, 178.0),
@@ -126,9 +98,9 @@ class Test_Listeners ( unittest.TestCase ):
             })
 
         # Adding alternate listener
-        ge.add_trait_listener( le, 'alt' )
+        ge.add_trait_listener(le, 'alt')
         events = {}
-        ge.set( name = 'Gertrude', age = 39, weight = 108.0 )
+        ge.set(name='Gertrude', age=39, weight=108.0)
         self.assertEqual(events, {
             '_age_changed': ('age', 34, 39),
             '_name_changed': ('name', 'Mike', 'Gertrude'),
@@ -138,18 +110,18 @@ class Test_Listeners ( unittest.TestCase ):
             })
 
         # Removing default listener
-        ge.remove_trait_listener( le )
+        ge.remove_trait_listener(le)
         events = {}
-        ge.set( name = 'Sally', age = 46, weight = 118.0 )
+        ge.set(name='Sally', age=46, weight=118.0)
         self.assertEqual(events, {
             'alt_name_changed': ('name', 'Gertrude', 'Sally'),
             'alt_weight_changed': ('weight', 108.0, 118.0),
             })
 
         # Removing alternate listener
-        ge.remove_trait_listener( le, 'alt' )
+        ge.remove_trait_listener(le, 'alt')
         events = {}
-        ge.set( name = 'Ralph', age = 29, weight = 198.0 )
+        ge.set(name='Ralph', age=29, weight=198.0)
         self.assertEqual(events, {})
 
 
@@ -176,7 +148,7 @@ class TestRaceCondition(unittest.TestCase):
             handler=lambda *args: None,
             reraise_exceptions=True,
             main=True,
-        )
+            )
 
     def tearDown(self):
         pop_exception_handler()
@@ -233,7 +205,7 @@ class TestRaceCondition(unittest.TestCase):
             t = threading.Thread(
                 target=worker_thread,
                 args=(event_source, start_event),
-            )
+                )
             t.start()
             main_thread(event_source, start_event)
             t.join()
