@@ -1,4 +1,4 @@
-#-------------------------------------------------------------------------------
+#------------------------------------------------------------------------------
 #
 #  Copyright (c) 2007, Enthought, Inc.
 #  All rights reserved.
@@ -10,7 +10,7 @@
 #
 #  Thanks for using Enthought open source!
 #
-#-------------------------------------------------------------------------------
+#------------------------------------------------------------------------------
 
 from __future__ import absolute_import
 
@@ -19,6 +19,7 @@ from traits.testing.unittest_tools import unittest
 from ..api import HasTraits, Trait, TraitError, TraitHandler
 from ..trait_base import strx
 
+
 # Validation via function
 def validator(object, name, value):
     if isinstance(value, basestring):
@@ -30,17 +31,18 @@ def validator(object, name, value):
     else:
         raise TraitError
 
+
 # Validation via Handler
 class MyHandler(TraitHandler):
-    def validate ( self, object, name, value ):
+    def validate(self, object, name, value):
         #print 'myvalidate "%s" %s' % (value, type(value))
         try:
-            value = strx( value )
+            value = strx(value)
             if value.find('fail') < 0:
                 return value
         except:
             pass
-        self.error( object, name, value )
+        self.error(object, name, value)
 
         return
 
@@ -48,23 +50,26 @@ class MyHandler(TraitHandler):
         msg = "a string not containing the character sequence 'fail'"
         return msg
 
+
 class Foo(HasTraits):
     s = Trait('', validator)
 
+
 class Bar(HasTraits):
-    s = Trait('', MyHandler() )
+    s = Trait('', MyHandler())
+
 
 class StrHandlerCase(unittest.TestCase):
 
     def test_validator_function(self):
         f = Foo()
-        self.failUnlessEqual( f.s, '' )
+        self.failUnlessEqual(f.s, '')
 
         f.s = 'ok'
-        self.failUnlessEqual( f.s, 'ok' )
+        self.failUnlessEqual(f.s, 'ok')
 
-        self.failUnlessRaises( TraitError, setattr, f, 's', 'should fail.')
-        self.failUnlessEqual( f.s, 'ok' )
+        self.failUnlessRaises(TraitError, setattr, f, 's', 'should fail.')
+        self.failUnlessEqual(f.s, 'ok')
 
         return
 
@@ -75,10 +80,9 @@ class StrHandlerCase(unittest.TestCase):
         b.s = 'ok'
         self.failUnlessEqual(b.s, 'ok')
 
-        self.failUnlessRaises( TraitError, setattr, b, 's', 'should fail.')
-        self.failUnlessEqual( b.s, 'ok')
+        self.failUnlessRaises(TraitError, setattr, b, 's', 'should fail.')
+        self.failUnlessEqual(b.s, 'ok')
 
         return
 
 ### EOF
-
